use chrono::{DateTime, TimeZone, Local, Utc};
use crate::common;
use crate::bar_modules;
use chrono_tz::{OffsetName, Tz};

#[derive(Clone)]
pub struct UnibarModuleTime {
    opts:       common::AppOptions,
    date_time:  DateTime<Local>,
    time_zone:  String,
}

impl UnibarModuleTime {
    // --------------------
    pub fn new(o :common::AppOptions) -> Self {
        UnibarModuleTime {
            opts:       o,
            date_time:  Local::now(),
            time_zone:  "".to_string(),
        }
    }
}

impl bar_modules::BarModuleActions for UnibarModuleTime {

    // --------------------
    fn clear(&mut self) {
        self.date_time = Local::now();
        self.time_zone = "".to_string();
    }

    // --------------------
    fn generate_data(&mut self) {
        match iana_time_zone::get_timezone() {
            Ok(tz_str) => {
                let tz: Tz = tz_str.parse().expect("Trouble parsing timezone string");
                let offset = tz.offset_from_utc_date(&Utc::now().date_naive());
                self.time_zone = offset.abbreviation()
                                 .expect("Trouble abbreviating timezone")
                                 .to_string();
            }
            Err(e) => {
                eprintln!("Trouble getting timezone: {e}");
            }
        }
        if self.opts.debug {
            println!("-----> Time dump {:#?}", self.date_time);
        }
    }

    // --------------------
    fn get_content(&self) -> String {
        return format!("{} {}", self.date_time.format("%I:%M%p"), self.time_zone);
    }

    // --------------------
    fn get_icon(&self) -> String {
        return "🕑".to_string();
    }
}

impl bar_modules::BarModuleDebug for UnibarModuleTime {

    // --------------------
    fn post_debug(&self) {
    }
}
